#include <functional>
#include <cmath>
#include <vector>
#include <iostream>
#include <algorithm>

using namespace std;

const double eps = 1e-6;
const double inf = 1e6;
const double magic = sqrt(3) / 2;

struct point {
  double x, y;
};

point operator+(point a, point b) {
  return point{a.x + b.x, a.y + b.y};
}

point operator-(point a, point b) {
  return point{a.x - b.x, a.y - b.y};
}

point operator*(double a, point v) {
  return point{a * v.x, a * v.y};
}

point perp(point a) {
  return point{-a.y, a.x};
}

double operator*(point a, point b) {
  return a.x * b.x + a.y * b.y;
}

double len(point a) {
  return sqrt(a * a);
}

double dist(point a, point b) {
  return len(a - b);
}

double ternaria(double a, double b, function<double(double)> f) {
  if (b - a < eps) return (f(a) + f(b)) / 2;
  double l = (2 * a + b) / 3, r = (a + 2 * b) / 3;
  double fl = f(l), fr = f(r);
  if (fl < fr) return ternaria(a, r, f);
  return ternaria(l, b, f);
}

double fermat(point a, point b, point c) {
  double ab = dist(a, b), ac = dist(a, c), bc = dist(b, c);
  double lens[3] = {ab, ac, bc};
  point v = b - a;
  point nap1 = a + 0.5 * v + magic * perp(v);
  point nap2 = a + 0.5 * v - magic * perp(v);
  return max(dist(c, nap1), dist(c, nap2));
}

int main() {
  cout.setf(ios::fixed);
  cout.precision(10);
  const int n = 3;
  vector<point> pts(n);
  for (int i = 0; i < n; ++i) cin >> pts[i].x >> pts[i].y;
  cout << ternaria(-inf, inf, [&](double x) {
      return ternaria(-inf, inf, [&](double y) {
          point p{x, y};
          double ans = 0;
          for (int i = 0; i < n; ++i) {
            for (int j = i + 1; j < n; ++j) {
              ans = max(ans, fermat(pts[i], pts[j], p));
            }
          }
          return ans;
          });
        }) << endl;
}
